@@ -6,7 +6,7 @@ def get_resource(filename):
     return pkgutil.get_data(__package__, 'data/' + filename)
 
 
-version = '0.4.1'
+version = '0.4.2'
 
 categories = json.loads(get_resource('categories.json').decode())
 sorts = json.loads(get_resource('sorts.json').decode())
@@ -16,4 +16,4 @@ default_headers = {'User-Agent': 'pirate get'}
 default_timeout = 10
 
 default_mirror = 'https://apibay.org'
-mirror_list = 'https://proxybay.bz/list.txt'
+mirror_list = 'https://proxy-bay.app/list.txt'
