@@ -3,6 +3,5 @@ import os
 def data_path(name):
     return os.path.join(os.path.dirname(os.path.realpath(__file__)), 'data', name)
 
-def read_data(name):
-    with open(data_path(name)) as f:
-        return f.read()
+def open_data(name):
+    return open(data_path(name))
